@@ -58,12 +58,12 @@ public:
 		struct line *next;
 		union {
 			const char *cmd;
-			script::header *sub;
+			header *sub;
 		};
 		char **argv;
 		unsigned short loop, argc; 
 		unsigned lnum, mask;
-		script::method_t method;
+		method_t method;
 	} line_t;
 
 	/**
@@ -80,7 +80,7 @@ public:
 	{
 	public:
 		const char *name;			/**< name of command */
-		script::method_t method;	/**< runtime method or NULL if c-t only */
+		method_t method;	/**< runtime method or NULL if c-t only */
 		check_t check;				/**< compile-time check routine */
 		struct keyword *next;		/**< linked list set by assign() */
 	} keyword_t;
@@ -98,10 +98,10 @@ public:
 		const char *id;
 
 	public:
-		static bool find(script *img, script::header *scr, const char *id);
-		static void createVar(script *img, script::header *scr, const char *id);
-		static void createSym(script *img, script::header *scr, const char *id);
-		static void createAny(script *img, script::header *scr, const char *id);
+		static bool find(script *img, header *scr, const char *id);
+		static void createVar(script *img, header *scr, const char *id);
+		static void createSym(script *img, header *scr, const char *id);
+		static void createAny(script *img, header *scr, const char *id);
 		static void createGlobal(script *img, const char *id);
 
 		void put(FILE *fp, const char *header);
@@ -131,10 +131,15 @@ public:
 	class __EXPORT event : public LinkedObject
 	{
 	public:
-		script::line_t *first;
+		line_t *first;
 		const char *name;
 	};
 
+	/**
+	 * Convenience typedef to allow use of event name.
+	 */
+	typedef	event event_t;
+
 	/**
 	 * Header describes a script section.  A section might be a named
 	 * label or a defined function.  Each section has a list of one or
@@ -149,7 +154,7 @@ public:
 		LinkedObject *scoped;	/**< scoped symbol defs */
 		LinkedObject *events;	/**< named events */
 		LinkedObject *methods;	/**< named members */
-		script::line_t *first;	/**< first line of section or define */
+		line_t *first;			/**< first line of section or define */
 		const char *name;		/**< name of script section or define */
 		unsigned resmask;		/**< post-compile processing resource mask */
 
@@ -174,43 +179,43 @@ public:
 		static bool isValue(const char *text);
 		static bool isText(const char *text);
 
-		static const char *chkPush(script *img, script::header *scr, script::line_t *line);
-		static const char *chkApply(script *img, script::header *scr, script::line_t *line);
-		static const char *chkIgnore(script *img, script::header *scr, script::line_t *line);
-		static const char *chkNop(script *img, script::header *scr, script::line_t *line);
-		static const char *chkExit(script *img, script::header *scr, script::line_t *line);
-		static const char *chkVar(script *img, script::header *scr, script::line_t *line);
-		static const char *chkConst(script *img, script::header *scr, script::line_t *line);
-		static const char *chkSet(script *img, script::header *scr, script::line_t *line);
-		static const char *chkClear(script *img, script::header *scr, script::line_t *line);
-		static const char *chkError(script *img, script::header *scr, script::line_t *line);
-		static const char *chkPack(script *img, script::header *scr, script::line_t *line);
-		static const char *chkExpand(script *img, script::header *scr, script::line_t *line);
-		static const char *chkGosub(script *img, script::header *src, script::line_t *line);
-		static const char *chkGoto(script *img, script::header *scr, script::line_t *line);
-		static const char *chkDo(script *img, script::header *scr, script::line_t *line);
-		static const char *chkUntil(script *img, script::header *scr, script::line_t *line);
-		static const char *chkWhile(script *ing, script::header *scr, script::line_t *line);
-		static const char *chkConditional(script *img, script::header *scr, script::line_t *line);
-		static const char *chkContinue(script *img, script::header *scr, script::line_t *line);
-		static const char *chkBreak(script *img, script::header *scr, script::line_t *line);
-		static const char *chkLoop(script *img, script::header *scr, script::line_t *line);
-		static const char *chkPrevious(script *img, script::header *scr, script::line_t *line);
-		static const char *chkIndex(script *img, script::header *scr, script::line_t *line);
-		static const char *chkForeach(script *img, script::header *scr, script::line_t *line);
-		static const char *chkCase(script *img, script::header *scr, script::line_t *line);
-		static const char *chkEndcase(script *img, script::header *scr, script::line_t *line);
-		static const char *chkOtherwise(script *img, script::header *scr, script::line_t *line);
-		static const char *chkIf(script *img, script::header *scr, script::line_t *line);
-		static const char *chkElif(script *img, script::header *scr, script::line_t *line);
-		static const char *chkElse(script *img, script::header *scr, script::line_t *line);
-		static const char *chkEndif(script *img, script::header *scr, script::line_t *line);
-		static const char *chkDefine(script *img, script::header *scr, script::line_t *line);
-		static const char *chkInvoke(script *img, script::header *scr, script::line_t *line);
-		static const char *chkWhen(script *img, script::header *scr, script::line_t *line);
-		static const char *chkStrict(script *img, script::header *scr, script::line_t *line);
-		static const char *chkExpr(script *img, script::header *scr, script::line_t *line);
-		static const char *chkRef(script *ing, script::header *scr, script::line_t *line); 
+		static const char *chkPush(script *img, header *scr, line_t *line);
+		static const char *chkApply(script *img, header *scr, line_t *line);
+		static const char *chkIgnore(script *img, header *scr, line_t *line);
+		static const char *chkNop(script *img, header *scr, line_t *line);
+		static const char *chkExit(script *img, header *scr, line_t *line);
+		static const char *chkVar(script *img, header *scr, line_t *line);
+		static const char *chkConst(script *img, header *scr, line_t *line);
+		static const char *chkSet(script *img, header *scr, line_t *line);
+		static const char *chkClear(script *img, header *scr, line_t *line);
+		static const char *chkError(script *img, header *scr, line_t *line);
+		static const char *chkPack(script *img, header *scr, line_t *line);
+		static const char *chkExpand(script *img, header *scr, line_t *line);
+		static const char *chkGosub(script *img, header *src, line_t *line);
+		static const char *chkGoto(script *img, header *scr, line_t *line);
+		static const char *chkDo(script *img, header *scr, line_t *line);
+		static const char *chkUntil(script *img, header *scr, line_t *line);
+		static const char *chkWhile(script *ing, header *scr, line_t *line);
+		static const char *chkConditional(script *img, header *scr, line_t *line);
+		static const char *chkContinue(script *img, header *scr, line_t *line);
+		static const char *chkBreak(script *img, header *scr, line_t *line);
+		static const char *chkLoop(script *img, header *scr, line_t *line);
+		static const char *chkPrevious(script *img, header *scr, line_t *line);
+		static const char *chkIndex(script *img, header *scr, line_t *line);
+		static const char *chkForeach(script *img, header *scr, line_t *line);
+		static const char *chkCase(script *img, header *scr, line_t *line);
+		static const char *chkEndcase(script *img, header *scr, line_t *line);
+		static const char *chkOtherwise(script *img, header *scr, line_t *line);
+		static const char *chkIf(script *img, header *scr, line_t *line);
+		static const char *chkElif(script *img, header *scr, line_t *line);
+		static const char *chkElse(script *img, header *scr, line_t *line);
+		static const char *chkEndif(script *img, header *scr, line_t *line);
+		static const char *chkDefine(script *img, header *scr, line_t *line);
+		static const char *chkInvoke(script *img, header *scr, line_t *line);
+		static const char *chkWhen(script *img, header *scr, line_t *line);
+		static const char *chkStrict(script *img, header *scr, line_t *line);
+		static const char *chkExpr(script *img, header *scr, line_t *line);
+		static const char *chkRef(script *ing, header *scr, line_t *line); 
 	};
 
 	/**
@@ -218,10 +223,10 @@ public:
 	 * manage loop and case blocks, as well as subroutine calls.
 	 */
 	typedef struct {
-		script::header *scr;	/**< executing script for stack */
-		script::header *scope;	/**< effective symbol scope */
-		script::event *event;	/**< so we don't redo our event */
-		script::line_t *line;	/**< executing line at stack level */
+		header *scr;			/**< executing script for stack */
+		header *scope;			/**< effective symbol scope */
+		event_t *event;			/**< so we don't redo our event */
+		line_t *line;			/**< executing line at stack level */
 		unsigned short index;	/**< index marker for loops */
 		unsigned short base;	/**< base stack of "@section" */
 		unsigned short resmask;	/**< effective dsp resource mask */
@@ -287,7 +292,7 @@ public:
 		unsigned getResource(void);
 
 	protected:
-		script::symbol *find(const char *id);
+		symbol *find(const char *id);
 		void skip(void);
 		void push(void);
 		bool trylabel(const char *id);
@@ -296,7 +301,7 @@ public:
 		void pullBase(void);
 		void pullLoop(void);
 		bool pop(void);
-		void setStack(script::header *scr, script::event *ev = NULL);
+		void setStack(header *scr, event *ev = NULL);
 		
 		/**
 		 * Define pattern match virtual.  This is used for the "$"
@@ -330,7 +335,7 @@ public:
 		 * @param name to search for.
 		 * @retrn method if found.
 		 */
-		script::event *scriptMethod(const char *name);
+		event *scriptMethod(const char *name);
 		
 		stack_t *stack;
 		pointer<script> image;
@@ -339,21 +344,21 @@ public:
 
 		char *getTemp(void);
 		bool setConst(const char *id, const char *value);
-		script::symbol *createSymbol(const char *id);
-		script::symbol *getVar(const char *id, const char *value = NULL);
+		symbol *createSymbol(const char *id);
+		symbol *getVar(const char *id, const char *value = NULL);
 		const char *getValue(void);
 		const char *getContent(void);
 		const char *getContent(const char *text);
 		const char *getKeyword(const char *id);
-		script::method_t getLooping(void);
+		method_t getLooping(void);
 		bool isConditional(unsigned index);
-		void setRef(script::header *scope, const char *id, char *data, unsigned size);
-		void getParams(script::header *scope, script::line_t *line);
-		void startScript(script::header *scr);
+		void setRef(header *scope, const char *id, char *data, unsigned size);
+		void getParams(header *scope, line_t *line);
+		void startScript(header *scr);
 
 		virtual unsigned getTypesize(const char *type_id);
 		virtual const char *getTypeinit(const char *type_id);
-		virtual const char *getFormat(script::symbol *sym, const char *id, char *temp);
+		virtual const char *getFormat(symbol *sym, const char *id, char *temp);
 		virtual bool getCondition(const char *test, const char *value);
 		const char *getIndex(void);
 
@@ -389,7 +394,7 @@ public:
 	 * derived from interp to collect implimentations for convenience.
 	 * @author David Sugar <dyfet@gnutelephony.org>
 	 */
-	class __EXPORT methods : public script::interp
+	class __EXPORT methods : public interp
 	{
 	public:	
 		bool scrPush(void);
@@ -442,16 +447,30 @@ public:
 	static unsigned stacking;	/**< stack frames in script runtime */
 	static unsigned decimals;	/**< default decimal places */
 
+	/**
+	 * Append a file into an existing image.  A shared config script can be
+     * used that holds common definitions.  Multiple script files can also be
+	 * merged together into a final image.
+	 * @param filename to compile.
+	 * @param config image of script with common definitions.
+	 * @param merge with prior compiled script.
+	 * @return compiled script object if successful.
+	 */
+	static script *append(script *merge, const char *filename, script *config = NULL);
+
 	/**
 	 * Compile a script file into an image.  Creates the new image that
 	 * will be used.  A shared config script can be compiled and used
 	 * to hold common definitions.
 	 * @param filename to compile.
 	 * @param config image of script with common definitions.
+	 * @param merge with prior compiled script.
 	 * @return compiled script object if successful.
 	 */
 	static script *compile(const char *filename, script *config = NULL);
 
+
+
 	/**
 	 * Compile and merge a script into an existing shared image.  This 
 	 * is related to compile, but the target script's definitions are
@@ -492,7 +511,7 @@ public:
 	static header *find(script *img, const char *id);
 	static bool isEvent(header *scr, const char *id);
 
-	script::header *first;
+	header *first;
 	LinkedObject **scripts;
 
 	bool push(line_t *line);
@@ -515,7 +534,11 @@ public:
 		{return lines;};
 
 private:
-	friend class script::strict;
+	friend class strict;
+	friend class checks;
+	friend class error;
+	friend class interp;
+	friend class methods;
 
 	script();
 
@@ -527,7 +550,6 @@ private:
 	bool thencheck;
 	line_t **stack;
 	LinkedObject *global;
-
 	OrderedIndex errlist;
 	pointer<script> shared;
 	const char *filename;
