@@ -47,7 +47,7 @@ static const char *getKeyword(const char *kw, script::line_t *line)
 
 	while(index < line->argc) {
 		cp = line->argv[index++];
-		if(*cp == '=' && String::equal(kw, ++cp))
+		if(*cp == '=' && eq(kw, ++cp))
 			return line->argv[index];	
 	}
 	return NULL;
@@ -82,7 +82,7 @@ static unsigned getRequired(script::line_t *line)
 			++index;
 			continue;
 		}
-		if(String::equal(cp, "required"))
+		if(eq(cp, "required"))
 			++count;
 	}
 	return count;
@@ -204,7 +204,7 @@ const char *script::checks::chkStrict(script *img, script::header *scr, script::
 	unsigned index = 0;
 	const char *cp;
 
-	if(!String::equal(scr->name, "_init_"))
+	if(!eq(scr->name, "_init_"))
 		return "strict can only be used in initialization section";
 
 	if(scr->first) 
@@ -271,7 +271,7 @@ const char *script::checks::chkIf(script *img, script::header *scr, script::line
 
 const char *script::checks::chkWhile(script *img, script::header *scr, script::line_t *line)
 {
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(img->thencheck)
@@ -322,7 +322,7 @@ const char *script::checks::chkForeach(script *img, script::header *scr, script:
 {
 	const char *cp;
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(img->thencheck)
@@ -365,7 +365,7 @@ const char *script::checks::chkForeach(script *img, script::header *scr, script:
 
 const char *script::checks::chkDo(script *img, script::header *scr, script::line_t *line)
 {
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(img->thencheck)
@@ -403,7 +403,7 @@ const char *script::checks::chkEndcase(script *img, script::header *scr, script:
 	if(img->thencheck)
 		return "cannot endcase in if-then clause";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(method != (method_t)&script::methods::scrCase && method != (method_t)&script::methods::scrOtherwise)
@@ -423,7 +423,7 @@ const char *script::checks::chkLoop(script *img, script::header *scr, script::li
 	if(img->thencheck)
 		return "can not end loop in if-then clause";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(method == (method_t)&script::methods::scrWhile)
@@ -454,7 +454,7 @@ const char *script::checks::chkCase(script *img, script::header *scr, script::li
 	if(img->thencheck)
 		return "cannot create case in if-then clause";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(method == (method_t)&script::methods::scrOtherwise) 
@@ -523,7 +523,7 @@ const char *script::checks::chkOtherwise(script *img, script::header *scr, scrip
 	if(img->thencheck)
 		return "cannot have otherwise if-then clause";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(method != (method_t)&script::methods::scrCase) {
@@ -548,7 +548,7 @@ const char *script::checks::chkUntil(script *img, script::header *scr, script::l
 	if(img->thencheck)
 		return "cannot have until in if-then clause";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(method == (method_t)NULL || method != (method_t)&script::methods::scrDo)
@@ -570,7 +570,7 @@ const char *script::checks::chkExit(script *img, script::header *scr, script::li
 	if(line->argc)
 		return "arguments are not used for this command";
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	return NULL;
@@ -585,7 +585,7 @@ const char *script::checks::chkInvoke(script *img, script::header *scr, script::
 	unsigned index = 0;
 	const char *cp, *kw;
 		
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(count < required)
@@ -599,7 +599,7 @@ const char *script::checks::chkInvoke(script *img, script::header *scr, script::
 		kw = sub->argv[index++];
 		if(*kw == '=') {
 			cp = sub->argv[index++];
-			if(String::equal(cp, "required") && !getKeyword(++kw, line))
+			if(eq(cp, "required") && !getKeyword(++kw, line))
 				return "required keyword missing";
 		}
 	}
@@ -638,9 +638,9 @@ const char *script::checks::chkDefine(script *img, script::header *scr, script::
 		}
 
 		if(isalpha(*cp)) {
-			if(String::equal(cp, "optional")) 
+			if(eq(cp, "optional")) 
 				line->argv[index - 1] = (char *)"&";	// rewrite to null
-			else if(!String::equal(cp, "required"))
+			else if(!eq(cp, "required"))
 				return "invalid keyword used in prototype";
 		}
 		else if(!isValue(cp))
@@ -740,9 +740,9 @@ const char *script::checks::chkSet(script *img, script::header *scr, script::lin
 		return "no symbols to assign";
 
 	if(line->argc > 2) {
-		if(String::equal(line->argv[1], ":="))
+		if(eq(line->argv[1], ":="))
 			drop = 1;
-		else if(String::equal(line->argv[1], "+=")) {
+		else if(eq(line->argv[1], "+=")) {
 			drop = 1;
 			line->method = (method_t)&methods::scrAdd;
 		}
@@ -857,7 +857,7 @@ const char *script::checks::chkGoto(script *img, script::header *scr, script::li
 	unsigned index = 0;
 	const char *cp;
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(line->argc < 1)
@@ -876,7 +876,7 @@ const char *script::checks::chkGosub(script *img, script::header *scr, script::l
 	unsigned index = 0;
 	const char *cp;
 
-	if(String::equal(scr->name, "_init_"))
+	if(eq(scr->name, "_init_"))
 		return "this command cannot be used to initialize";
 
 	if(line->argc < 1)
@@ -914,7 +914,7 @@ const char *script::checks::chkConditional(script *img, script::header *scr, scr
 
 			cp = line->argv[index++];
 
-			if(*cp != '?' && !String::equal(cp, "eq") && !String::equal(cp, "ne") && !String::equal(cp, "lt") && !String::equal(cp, "gt") && !String::equal(cp, "le") && !String::equal(cp, "ge") && !String::equal(cp, "is") && !String::equal(cp, "isnot") && !String::equal(cp, "in") && !String::equal(cp, "notin"))
+			if(*cp != '?' && !eq(cp, "eq") && !eq(cp, "ne") && !eq(cp, "lt") && !eq(cp, "gt") && !eq(cp, "le") && !eq(cp, "ge") && !eq(cp, "is") && !eq(cp, "isnot") && !eq(cp, "in") && !eq(cp, "notin"))
 				return "invalid operator in expression";
 
 			if(index >= line->argc)
@@ -928,7 +928,7 @@ const char *script::checks::chkConditional(script *img, script::header *scr, scr
 			return NULL;
 
 		cp = line->argv[index++];
-		if(String::equal("?&&", cp) || String::equal("?||", cp) || String::equal("and", cp) || String::equal("or", cp))
+		if(eq("?&&", cp) || eq("?||", cp) || eq("and", cp) || eq("or", cp))
 			continue;
 
 		return "invalid expression joiner statement";
@@ -962,7 +962,7 @@ valid:
 		cp = getArgument(line, &index);
 		if(!cp)
 			break;
-		if(!String::equal(cp, "*") && !String::equal(cp, "/") && !String::equal(cp, "+") && !String::equal(cp, "-") && !String::equal(cp, "#"))
+		if(!eq(cp, "*") && !eq(cp, "/") && !eq(cp, "+") && !eq(cp, "-") && !eq(cp, "#"))
 			return "invalid expression used";
 		if(index == line->argc)
 			return "incomplete expression";
@@ -982,7 +982,7 @@ const char *script::checks::chkExpr(script *img, script::header *scr, script::li
 	while(index < line->argc) {
 		cp = line->argv[index++];
 		if(*cp == '=') {
-			if(!String::equal(cp, "=decimals"))
+			if(!eq(cp, "=decimals"))
 				return "invalid keyword for expression";
 			++index;
 		}
@@ -1011,7 +1011,7 @@ const char *script::checks::chkExpr(script *img, script::header *scr, script::li
 	if(!cp)
 		return "expression incomplete";
 
-	if(!String::equal(cp, ":=") && !String::equal(cp, "?=") && !String::equal(cp, "+=") && !String::equal(cp, "-=") && !String::equal(cp, "*=") && !String::equal(cp, "/="))
+	if(!eq(cp, ":=") && !eq(cp, "?=") && !eq(cp, "+=") && !eq(cp, "-=") && !eq(cp, "*=") && !eq(cp, "/="))
 		return "expression must start with assignment expression";
 
 	while(index < line->argc) {
@@ -1022,7 +1022,7 @@ const char *script::checks::chkExpr(script *img, script::header *scr, script::li
 		cp = getArgument(line, &index);
 		if(!cp)
 			break;
-		if(!String::equal(cp, "*") && !String::equal(cp, "/") && !String::equal(cp, "+") && !String::equal(cp, "-") && !String::equal(cp, "#"))
+		if(!eq(cp, "*") && !eq(cp, "/") && !eq(cp, "+") && !eq(cp, "-") && !eq(cp, "#"))
 			return "invalid expression used";
 		if(index == line->argc)
 			return "incomplete expression";
