@@ -114,7 +114,7 @@ static bool preparse(char **tokens)
 		return false;
 #endif
 	case '>':
-		if(String::equal(str, ">>%", 3)) {
+		if(eq(str, ">>%", 3)) {
 			--*tokens;
 			--str;
 			str[0] = '$';
@@ -142,7 +142,7 @@ static bool preparse(char **tokens)
 		}
 		return false;
 	case '<':
-		if(String::equal(str, "<<%", 3)) {
+		if(eq(str, "<<%", 3)) {
 			--*tokens;
 			--str;
 			str[0] = '$';
@@ -217,7 +217,7 @@ static bool preparse(char **tokens)
 	case '_':
 		return false;
 	case '+':
-		if(String::equal(str, "++%", 3)) {
+		if(eq(str, "++%", 3)) {
 			--*tokens;
 			--str;
 			str[0] = '$';
@@ -238,7 +238,7 @@ static bool preparse(char **tokens)
 			break;
 		return false;
 	case '-':
-		if(String::equal(str, "--%", 3)) {
+		if(eq(str, "--%", 3)) {
 			--*tokens;
 			--str;
 			str[0] = '$';
@@ -292,12 +292,15 @@ CountedObject(), memalloc()
 	first = NULL;
 	global = NULL;
 	headers = NULL;
+	stack = NULL;
 	scripts = (LinkedObject **)alloc(sizeof(LinkedObject **) * script::indexing);
 	memset(scripts, 0, sizeof(LinkedObject **) * script::indexing);
 }
 
 script::~script()
 {
+	if(stack)
+		delete[] stack;
 	shared = NULL;
 }
 
@@ -329,7 +332,7 @@ script::keyword_t *script::find(const char *cmd)
 	keyword_t *keyword = keywords;
 	
 	while(keyword != NULL) {
-		if(String::equal(cmd, keyword->name))
+		if(eq(cmd, keyword->name))
 			break;
 		keyword = keyword->next;
 	}
@@ -397,7 +400,7 @@ script::header *script::find(script *img, const char *id)
 	linked_pointer<header> hp = img->scripts[path];
 
 	while(is(hp)) {
-		if(String::equal(hp->name, id))
+		if(eq(hp->name, id))
 			break;
 
 		hp.next();
@@ -426,8 +429,13 @@ script *script::merge(const char *fn, script *root)
 
 	return img;
 }	
-	
+
 script *script::compile(const char *fn, script *cfg)
+{
+	return script::append(NULL, fn, cfg);
+}
+	
+script *script::append(script *merge, const char *fn, script *cfg)
 {
 //	linked_pointer<script::strict> sp;
 
@@ -463,8 +471,13 @@ script *script::compile(const char *fn, script *cfg)
 	if(!fp)
 		return NULL;
 
-	img = new script();
-	img->stack = new line_t*[script::stacking];
+	if(merge)
+		img = merge;
+	else 
+		img = new script();
+
+	if(!img->stack)
+		img->stack = new line_t*[script::stacking];
 
 	img->shared = cfg;
 	img->filename = strrchr(fn, '/');
@@ -481,6 +494,7 @@ initial:
 	current = NULL;
 	prior = NULL;
 	last = NULL;
+
 	scr = (header *)img->alloc(sizeof(header));
 	memset(scr, 0, sizeof(header));
 	scr->name = img->dup(name);
@@ -492,8 +506,11 @@ initial:
 	img->loop = 0;
 	char *temp;
 
-	path = NamedObject::keyindex(name, script::indexing);
-	scr->enlist(&img->scripts[path]);
+	// we drop additional initializers during append
+	if(!eq(name, "_init_") || !merge) {
+		path = NamedObject::keyindex(name, script::indexing);
+		scr->enlist(&img->scripts[path]);
+	}
 
 	if(!img->first)
 		img->first = scr;
@@ -543,7 +560,7 @@ initial:
 		tokens = NULL;
 		token = String::token(buffer.c_mem(), &tokens, " \t", "{}\'\'\"\"");
 
-		if(String::equal(token, "endreq") || String::equal(token, "endrequires")) {
+		if(eq(token, "endreq") || eq(token, "endrequires")) {
 			if(indented) {
 				img->errlog(lnum, "endreq cannot be indented");
 				continue;
@@ -551,7 +568,7 @@ initial:
 			requires = false;
 			continue;
 		}
-		else if(String::equal(token, "requires")) {
+		else if(eq(token, "requires")) {
 			if(indented) {
 				img->errlog(lnum, "requires cannot be indented");
 				continue;
@@ -605,7 +622,7 @@ initial:
 			goto closure;
 		}	
 
-		if(String::equal(token, "template")) {
+		if(eq(token, "template")) {
 			if(section) {
 				img->errlog(lnum, "templates must be before named sections");
 				continue;
@@ -621,7 +638,7 @@ initial:
 			goto closure;
 		}
 
-		if(String::equal(token, "define")) {
+		if(eq(token, "define")) {
 			if(section) {
 				img->errlog(lnum, "defines must be before named sections");
 				continue;
@@ -651,17 +668,17 @@ parse:
 		if(*token == '%') {
 			assigned = img->dup(token);
 			op = String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
-			if(op && (String::equal(op, ":=") || String::equal(op, "+=") || String::equal(op, "-=") || String::equal(op, "*=") || String::equal(op, "/=") || String::equal(op, "%=") || String::equal(op, "#=")))
+			if(op && (eq(op, ":=") || eq(op, "+=") || eq(op, "-=") || eq(op, "*=") || eq(op, "/=") || eq(op, "%=") || eq(op, "#=")))
 				token = "expr";
-			else if(op && (String::equal(op, "=") || String::equal(op, "==") || String::equal(op, "$="))) {
+			else if(op && (eq(op, "=") || eq(op, "==") || eq(op, "$="))) {
 				op = NULL;
 				token = "set";
 			}
-			else if(op && (String::equal(op, ".") || String::equal(op, ".="))) {
+			else if(op && (eq(op, ".") || eq(op, ".="))) {
 				op = NULL;
 				token = "add";
 			}
-			else if(op && (String::equal(op, ",") || String::equal(op, ",="))) {
+			else if(op && (eq(op, ",") || eq(op, ",="))) {
 				op = NULL;
 				token = "pack";
 			} 
@@ -736,12 +753,12 @@ parse:
 			if(!arg)
 				break;
 
-			if(String::equal(token, "if")) {
-				if(String::equal(arg, "if")) {
+			if(eq(token, "if")) {
+				if(eq(arg, "if")) {
 					formed = false;
 					break;
 				}
-				if(String::equal(arg, "then")) {
+				if(eq(arg, "then")) {
 					keyword = find("_ifthen");
 					line->method = keyword->method;
 					token = String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
@@ -880,6 +897,7 @@ closure:
 	fclose(fp);
 	delete[] argv;
 	delete[] img->stack;
+	img->stack = NULL;
 //	sp = img->global;
 //	while(is(sp)) {
 //		sp->put(stdout, "*");
@@ -894,7 +912,7 @@ bool script::isEvent(header *scr, const char *id)
 	linked_pointer<event> ep = scr->events;
 
 	while(is(ep)) {
-		if(String::equal(ep->name, id))
+		if(eq(ep->name, id))
 			return true;
 		ep.next();
 	}
@@ -1074,7 +1092,7 @@ bool script::strict::find(script* image, script::header *scr, const char *id)
 	if(*id != '%' && *id != '$')
 		return true;
 
-	if(String::equal(id, "$map/", 5)) {
+	if(eq(id, "$map/", 5)) {
 		buf[0] = '%';
 		String::set(buf + 1, sizeof(buf) - 1, id + 5);
 		ep = strchr(buf, ':');
