@@ -76,7 +76,7 @@ bool script::interp::error(const char *msg)
 	if(errmsg)
 		String::set(errmsg, 65, msg);
 
-	if(!String::equal(stack[frame].scr->name, "_init_")) {
+	if(!eq(stack[frame].scr->name, "_init_")) {
 		if(scriptEvent("error"))
 			return false;
 	}
@@ -118,9 +118,9 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 	while(isspace(*cp))
 		++cp;
 
-	if(String::equal(id, "len:", 4)) 
+	if(eq(id, "len:", 4)) 
 		snprintf(tp, script::sizing + 1, "%u", (unsigned)strlen(sym->data));
-	else if(String::equal(id, "key:", 4)) {
+	else if(eq(id, "key:", 4)) {
 		String::set(tp, script::sizing + 1, cp);
 		ep = strchr(tp, '=');
 		if(ep)
@@ -128,14 +128,14 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		else
 			String::set(tp, 2, "-");
 	}
-	else if(String::equal(id, "tail:", 5)) {
+	else if(eq(id, "tail:", 5)) {
 		dcount = script::count(sym->data);
 		if(dcount)
 			String::set(tp, script::sizing + 1, script::get(cp, --dcount));
 		else
 			tp[0] = 0;
 	}
-	else if(String::equal(id, "head:", 5)) {
+	else if(eq(id, "head:", 5)) {
 		String::set(tp, script::sizing + 1, sym->data);
 		if(script::count(tp) > 1) {
 			dcount = script::offset(tp, 1);
@@ -143,7 +143,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 				tp[--dcount] = 0;
 		}
 	}
-	else if(String::equal(id, "pull:", 5) || String::equal(id, "<<:", 3)) {
+	else if(eq(id, "pull:", 5) || eq(id, "<<:", 3)) {
 		String::set(tp, script::sizing + 1, sym->data);
 		if(script::count(tp) > 1) {
 			dcount = script::offset(tp, 1);
@@ -153,7 +153,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 			}
 		}
 	}
-	else if(String::equal(id, "pop:", 4) || String::equal(id, ">>:", 3)) {
+	else if(eq(id, "pop:", 4) || eq(id, ">>:", 3)) {
 		dcount = script::count(sym->data);
 		if(dcount) {
 			String::set(tp, script::sizing + 1, script::get(sym->data, --dcount));
@@ -167,7 +167,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		else
 			tp[0] = 0;
 	}		
-	else if(String::equal(id, "val:", 4) && (*cp == '\'' || *cp == '\"' || *cp == '(')) {
+	else if(eq(id, "val:", 4) && (*cp == '\'' || *cp == '\"' || *cp == '(')) {
 		String::set(tp, script::sizing + 1, cp + 1);
 		if(*cp == '(')
 			ep = strrchr(tp, ')');
@@ -176,7 +176,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		if(ep)
 			*ep = 0;
 	}
-	else if(String::equal(id, "val:", 4) && strchr(sym->data, '=')) {
+	else if(eq(id, "val:", 4) && strchr(sym->data, '=')) {
 		cp = strchr(sym->data, '=') + 1;
 		if(*cp == '\"' || *cp == '\'') {
 			String::set(tp, script::sizing + 1, cp + 1);
@@ -191,7 +191,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 				*ep = 0;
 		}
 	}  
-	else if(String::equal(id, "unquote:", 8) && sym->size) {
+	else if(eq(id, "unquote:", 8) && sym->size) {
 		cp = sym->data;
 		while(isspace(*cp))
 			++cp;
@@ -210,22 +210,22 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 		String::set(sym->data, sym->size + 1, cp);
 		return sym->data;
 	}
-	else if(String::equal(id, "upper:", 6) && sym->size) {
+	else if(eq(id, "upper:", 6) && sym->size) {
 		String::upper(sym->data);
 		return sym->data;
 	}
-	else if(String::equal(id, "lower:", 6) && sym->size) {
+	else if(eq(id, "lower:", 6) && sym->size) {
 		String::lower(sym->data);
 		return sym->data;
 	}	
-	else if((String::equal(id, "inc:", 4) || String::equal(id, "++:", 3)) && sym->size) {
+	else if((eq(id, "inc:", 4) || eq(id, "++:", 3)) && sym->size) {
 		val = atol(cp);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, ++val);
 		return sym->data;
 	}
-	else if(String::equal(id, "count:", 6))
+	else if(eq(id, "count:", 6))
 		snprintf(tp, script::sizing + 1, "%u", script::count(sym->data)); 
-	else if(String::equal(id, "index/", 6)) {
+	else if(eq(id, "index/", 6)) {
 		id += 6;
 		pos = atoi(id);
 		if(pos)
@@ -238,7 +238,7 @@ const char *script::interp::getFormat(script::symbol *sym, const char *id, char
 			cp = null;
 		script::copy(cp, tp, script::sizing);
 	}
-	else if(String::equal(id, "offset/", 7)) {
+	else if(eq(id, "offset/", 7)) {
 		id += 7;
 		pos = atoi(id);
 		if(pos)
@@ -249,18 +249,18 @@ offset:
 		cp = script::get(sym->data, pos);
 		script::copy(cp, tp, script::sizing);
 	}
-	else if((String::equal(id, "dec:", 4) || String::equal(id, "--:", 3)) && sym->size) {
+	else if((eq(id, "dec:", 4) || eq(id, "--:", 3)) && sym->size) {
 		val = atoi(cp);
 		snprintf(sym->data, sym->size + 1, NUM_FORMAT, --val);
 		return sym->data;
 	}
-	else if(String::equal(id, "size:", 5))
+	else if(eq(id, "size:", 5))
 		snprintf(tp, script::sizing + 1, "%d", sym->size);
-	else if(String::equal(id, "val:", 4) || !strnicmp(id, "int:", 4)) {
+	else if(eq(id, "val:", 4) || eq(id, "int:", 4)) {
 		val = atol(cp);
 		snprintf(tp, script::sizing + 1, NUM_FORMAT, val);
 	}
-	else if(String::equal(id, "num:", 4)) {
+	else if(eq(id, "num:", 4)) {
 		val = atol(cp);
 		snprintf(tp, script::sizing + 1, NUM_FORMAT, val);
 		if(script::decimals)
@@ -279,7 +279,7 @@ offset:
 		}
 		tp[pos] = 0; 		
 	}
-	else if(String::equal(id, "map/", 4)) {
+	else if(eq(id, "map/", 4)) {
 		idbuf[0] = '%';
 		String::set(idbuf, sizeof(idbuf), id + 4);
 		ep = strchr(idbuf, ':');
@@ -295,7 +295,7 @@ offset:
 		paren = 0;
 		goto search;
 	}
-	else if(String::equal(id, "find/", 5)) {
+	else if(eq(id, "find/", 5)) {
 		id += 5;
 		paren = 0;
 		dcount = 1;
@@ -340,7 +340,7 @@ search:
 		}
 		tp[dcount] = 0;
 	}
-	else if(String::equal(id, "bool:", 5)) {
+	else if(eq(id, "bool:", 5)) {
 		if(atoi(sym->data) > 0 || tolower(sym->data[0]) == 't' || tolower(sym->data[0] == 'y'))
 			snprintf(tp, script::sizing + 1, "true");
 		else
@@ -370,7 +370,7 @@ const char *script::interp::getContent(const char *cp)
 			return getFormat(sym, ++cp, tp);
 		}
 	case '%':
-		if(String::equal(cp, "%index"))
+		if(eq(cp, "%index"))
 			return getIndex();
 		sym = find(++cp);
 		if(sym)
@@ -395,7 +395,7 @@ const char *script::interp::getKeyword(const char *id)
 	while(index < line->argc) {
 		cp = line->argv[index++];
 		if(*cp == '=') {
-			if(String::equal(id, ++cp))
+			if(eq(id, ++cp))
 				return getContent(line->argv[index]);
 			++index;
 		}
@@ -477,7 +477,7 @@ bool script::interp::setConst(const char *id, const char *value)
 	sp = syms[path];
 
 	while(is(sp)) {
-		if(String::equal(sp->name, id) && sp->scope == stack[frame].scope)
+		if(eq(sp->name, id) && sp->scope == stack[frame].scope)
 			return false;
 		sp.next();
 	}
@@ -525,9 +525,9 @@ script::symbol *script::interp::createSymbol(const char *id)
 		size = script::sizing;
 
 	while(is(sp)) {
-		if(String::equal(sp->name, id) && sp->scope == NULL)
+		if(eq(sp->name, id) && sp->scope == NULL)
 			var = *sp;
-		if(String::equal(sp->name, id) && sp->scope == stack[frame].scope)
+		if(eq(sp->name, id) && sp->scope == stack[frame].scope)
 			local = *sp;
 		sp.next();
 	}
@@ -554,13 +554,13 @@ unsigned script::interp::getTypesize(const char *type_id)
 	if(!type_id)
 		return 0;
 
-	if(String::equal(type_id, "int"))
+	if(eq(type_id, "int"))
 		return 10;
 
-	if(String::equal(type_id, "num"))
+	if(eq(type_id, "num"))
 		return 20;
 
-	if(String::equal(type_id, "bool"))
+	if(eq(type_id, "bool"))
 		return 1;
 
 	return 0;
@@ -571,10 +571,10 @@ const char *script::interp::getTypeinit(const char *type_id)
 	if(!type_id)
 		return NULL;
 
-	if(String::equal(type_id, "int") || String::equal(type_id, "num"))
+	if(eq(type_id, "int") || eq(type_id, "num"))
 		return "0";
 
-	if(String::equal(type_id, "bool"))
+	if(eq(type_id, "bool"))
 		return "f";
 
 	return NULL;
@@ -601,7 +601,7 @@ void script::interp::getParams(script::header *scope, script::line_t *line)
 			snprintf(pbuf, sizeof(pbuf), "%d", ++param);
 			id = pbuf;
 		}
-		if(String::equal(cp, "required") || String::equal(cp, "optional"))
+		if(eq(cp, "required") || eq(cp, "optional"))
 			setRef(scope, id, const_cast<char *>(""), 0);
 		else if(*cp == '%') {
 			sym = find(++cp);
@@ -636,7 +636,7 @@ void script::interp::setRef(script::header *scope, const char *id, char *value,
 	sp = syms[path];
 
 	while(is(sp)) {
-		if(String::equal(sp->name, id) && sp->scope == scope) {
+		if(eq(sp->name, id) && sp->scope == scope) {
 			var = *sp;
 			break;
 		}
@@ -693,7 +693,7 @@ script::symbol *script::interp::getVar(const char *id, const char *value)
 		size = script::sizing;
 
 	while(is(sp)) {
-		if(String::equal(sp->name, id) && sp->scope == stack[frame].scope) {
+		if(eq(sp->name, id) && sp->scope == stack[frame].scope) {
 			var = *sp;
 			break;
 		}
@@ -731,7 +731,7 @@ script::symbol *script::interp::find(const char *id)
 	script::symbol *global = NULL, *local = NULL;
 
 	while(is(sp)) {
-		if(String::equal(sp->name, id)) {
+		if(eq(sp->name, id)) {
 			if(sp->scope == NULL)
 				global = *sp;
 			else if(sp->scope == stack[frame].scope)
@@ -756,7 +756,7 @@ void script::interp::startScript(script::header *scr)
 	linked_pointer<script::event> ep = scr->events;
 
 	while(is(ep)) {
-		if(String::equal(ep->name, "init")) {
+		if(eq(ep->name, "init")) {
 			push();
 			stack[frame].event = *ep;
 			stack[frame].line = ep->first;
@@ -979,7 +979,7 @@ bool script::interp::trylabel(const char *label)
 
 bool script::interp::tryexit(void)
 {
-	if(stack[frame].event && String::equal("exit", stack[frame].event->name))
+	if(stack[frame].event && eq("exit", stack[frame].event->name))
 		return false;
 
 	if(scriptEvent("exit"))
@@ -1023,7 +1023,7 @@ bool script::interp::getCondition(const char *test, const char *v)
 	unsigned points = 0;
 	script::symbol *sym;
 
-	if(String::equal(test, "defined")) {
+	if(eq(test, "defined")) {
 		if(!v)
 			return false;
 		if(*v == '%') {
@@ -1038,7 +1038,7 @@ bool script::interp::getCondition(const char *test, const char *v)
 		return true;
 	}
 	
-	if(String::equal(test, "const")) {
+	if(eq(test, "const")) {
 		if(!v)
 			return false;
 
@@ -1054,7 +1054,7 @@ bool script::interp::getCondition(const char *test, const char *v)
 			return false;
 	}
 
-	if(String::equal(test, "modify")) {
+	if(eq(test, "modify")) {
 		if(!v)
 			return false;
 
@@ -1071,13 +1071,13 @@ bool script::interp::getCondition(const char *test, const char *v)
 	}
 
 	v = getContent(v);
-	if(String::equal(test, "empty")) {
+	if(eq(test, "empty")) {
 		if(v && *v)
 			return false;
 		return true;
 	}
 
-	if(String::equal(test, "integer")) {
+	if(eq(test, "integer")) {
 		if(!v || !*v)
 			return false;
 
@@ -1092,7 +1092,7 @@ bool script::interp::getCondition(const char *test, const char *v)
 		return true;
 	}
 
-	if(String::equal(test, "digits")) {
+	if(eq(test, "digits")) {
 		if(!v || !*v)
 			return false;
 
@@ -1104,7 +1104,7 @@ bool script::interp::getCondition(const char *test, const char *v)
 		return true;
 	}
 
-	if(String::equal(test, "number")) {
+	if(eq(test, "number")) {
 		if(!v || !*v)
 			return false;
 
@@ -1149,13 +1149,13 @@ bool script::interp::isConditional(unsigned index)
 
 		cp = line->argv[index++];
 
-		if(String::equal(cp, "?&&") || String::equal(cp, "and")) {
+		if(eq(cp, "?&&") || eq(cp, "and")) {
 			if(!rtn)
 				return false;
 			rtn = false;
 			continue;
 		}
-		if(String::equal(cp, "?||") || String::equal(cp, "or")) {
+		if(eq(cp, "?||") || eq(cp, "or")) {
 			if(rtn)
 				return true;
 			rtn = false;
@@ -1174,7 +1174,7 @@ bool script::interp::getExpression(unsigned index)
 	unsigned len;
 	char dec1[9], dec2[9];
 	long dv1, dv2;
-	unsigned pos = 0, count;
+	unsigned pos = 0, pcount;
 
 #ifdef	__MINGW32__
 	long long dv;
@@ -1234,49 +1234,49 @@ bool script::interp::getExpression(unsigned index)
 		dec2[c2++] = '0';
 
 	dec1[8] = dec2[8] = 0;
-	if(String::equal(op, "=")) 
+	if(eq(op, "=")) 
 		return ((atol(v1) == atol(v2)) && !strcmp(dec1, dec2));
 
-	if(String::equal(op, "<>")) 
+	if(eq(op, "<>")) 
 		return ((atol(v1) != atol(v2)) || strcmp(dec1, dec2));
 
-	if(String::equal(op, "&&"))
+	if(eq(op, "&&"))
 		return (*v1 && *v2);
 
-	if(String::equal(op, "||"))
+	if(eq(op, "||"))
 		return (*v1 || *v2);
 
-	if(String::equal(op, "gt")) {
+	if(eq(op, "gt")) {
 		if(strcmp(v1, v2) > 0)
 			return true;
 		return false;
 	}
 
-	if(String::equal(op, "lt")) {
+	if(eq(op, "lt")) {
 		if(strcmp(v1, v2) < 0)
 			return true;
 		return false;
 	}
 
-	if(String::equal(op, "ge")) {
+	if(eq(op, "ge")) {
 		if(strcmp(v1, v2) >= 0)
 			return true;
 		return false;
 	}
 
-	if(String::equal(op, "le")) {
+	if(eq(op, "le")) {
 		if(strcmp(v1, v2) <= 0)
 			return true;
 		return false;
 	}
 
-	if(String::equal(op, "==") || String::equal(op, "eq"))
-		return String::equal(v1, v2);
+	if(eq(op, "==") || eq(op, "eq"))
+		return eq(v1, v2);
 
-	if(String::equal(op, "!=") || String::equal(op, "ne"))
-		return !String::equal(v1, v2);
+	if(eq(op, "!=") || eq(op, "ne"))
+		return !eq(v1, v2);
 
-	if(String::equal(op, "<")) {
+	if(eq(op, "<")) {
 		dv1 = atol(dec1);
 		dv2 = atol(dec2);
 		if(*v1 == '-') {
@@ -1286,7 +1286,7 @@ bool script::interp::getExpression(unsigned index)
 		return (atol(v1) < atol(v2) || (atol(v1) == atol(v2) && dv1 < dv2));
 	}
 
-	if(String::equal(op, "<=")) {
+	if(eq(op, "<=")) {
 		dv1 = atol(dec1);
 		dv2 = atol(dec2);
 		if(*v1 == '-') {
@@ -1296,7 +1296,7 @@ bool script::interp::getExpression(unsigned index)
 		return (atoi(v1) < atoi(v2) || (atol(v1) == atol(v2) && dv1 <= dv2));
 	}
 
-	if(String::equal(op, ">")) {
+	if(eq(op, ">")) {
 		dv1 = atol(dec1);
 		dv2 = atol(dec2);
 		if(*v1 == '-') {
@@ -1306,7 +1306,7 @@ bool script::interp::getExpression(unsigned index)
 		return (atol(v1) > atol(v2) || (atol(v1) == atol(v2) && dv1 > dv2));
 	}
 
-	if(String::equal(op, ">=")) {
+	if(eq(op, ">=")) {
 		dv1 = atol(dec1);
 		dv2 = atol(dec2);
 		if(*v1 == '-') {
@@ -1316,42 +1316,42 @@ bool script::interp::getExpression(unsigned index)
 		return (atol(v1) > atol(v2) || (atol(v1) == atol(v2) && dv1 >= dv2));
 	}
 
-	if(String::equal(op, "?") || String::equal(op, "in")) {
-		count = script::count(v2);
-		if(!count)
+	if(eq(op, "?") || eq(op, "in")) {
+		pcount = script::count(v2);
+		if(!pcount)
 			return false;
 
 		len = strlen(v1);
-		while(pos < count) {
+		while(pos < pcount) {
 			op = script::get(v2, pos++);
-			if(op && String::equal(v1, op, len) && (op[len] == ',' || op[len] == 0 || op[len] == '='))
+			if(op && eq(v1, op, len) && (op[len] == ',' || op[len] == 0 || op[len] == '='))
 				return true;
 		}
 		return false;
 	}
 
-	if(String::equal(op, "!?") || String::equal(op, "notin")) {
-		count = script::count(v2);
-		if(!count)
+	if(eq(op, "!?") || eq(op, "notin")) {
+		pcount = script::count(v2);
+		if(!pcount)
 			return true;
 
 		len = strlen(v1);
-		while(pos < count) {
+		while(pos < pcount) {
 			op = script::get(v2, pos++);
-			if(op && String::equal(v1, op, len) && (op[len] == ',' || op[len] == 0 || op[len] == '='))
+			if(op && eq(v1, op, len) && (op[len] == ',' || op[len] == 0 || op[len] == '='))
 				return false;
 		}
 		return true;
 	}
 
-	if(String::equal(op, "!$") || String::equal(op, "isnot"))
+	if(eq(op, "!$") || eq(op, "isnot"))
 		return !match(v2, v1);
 
-	if(String::equal(op, "$") || String::equal(op, "is"))
+	if(eq(op, "$") || eq(op, "is"))
 		return match(v2, v1);
 
 #ifdef	HAVE_REGEX_H
-	if(String::equal(op, "~") || String::equal(op, "!~")) {
+	if(eq(op, "~") || eq(op, "!~")) {
 		bool rtn = false;
 		regex_t *regex = new regex_t;
 		memset(regex, 0, sizeof(regex_t));
