@@ -44,7 +44,7 @@ bool script::methods::scrExpand(void)
 	unsigned index = 1;
 	script::line_t *line = stack[frame].line;
 	const char *tuples = getContent(line->argv[0]);
-	unsigned count = script::count(tuples);
+	unsigned tcount = script::count(tuples);
 	script::symbol *sym;
 	const char *cp;
 
@@ -60,7 +60,7 @@ bool script::methods::scrExpand(void)
 		if(!sym->size)
 			return error("symbol not writable");
 
-		if(index > count) 
+		if(index > tcount) 
 			String::set(sym->data, sym->size + 1, "");
 		else {
 			cp = script::get(tuples, index - 1);
@@ -494,9 +494,9 @@ bool script::methods::scrRef(void)
 
 bool script::methods::scrExpr(void)
 {
-	unsigned decimals = script::decimals;
+	unsigned exdecimals = script::decimals;
 	const char *id, *cp, *op, *aop;
-	float result, value;
+	double result, value;
 	long lvalue;
 	char cvt[8];
 	char buf[32];
@@ -505,7 +505,7 @@ bool script::methods::scrExpr(void)
 
 	cp = getKeyword("decimals");
 	if(cp)
-		decimals = atoi(cp);
+		exdecimals = atoi(cp);
 
 	id = getContent();
 	aop = getValue();
@@ -541,23 +541,23 @@ bool script::methods::scrExpr(void)
 		value = atof(cp);
 	else
 		value = 0;
-	if(String::equal(aop, "+="))
+	if(eq(aop, "+="))
 		value += result;
-	else if(String::equal(aop, "#="))
+	else if(eq(aop, "#="))
 		value = (long)value % (long)result;
-	else if(String::equal(aop, "-="))
+	else if(eq(aop, "-="))
 		value -= result;
-	else if(String::equal(aop, "*="))
+	else if(eq(aop, "*="))
 		value *= result;
-	else if(String::equal(aop, "/=") && result)
+	else if(eq(aop, "/=") && result)
 		value /= result;
-	else if(String::equal(aop, "?=") || String::equal(aop, ":="))
+	else if(eq(aop, "?=") || eq(aop, ":="))
 		value = result;
 
 	stack[frame].index = 0;
 	cvt[0] = '%';
 	cvt[1] = '.';
-	cvt[2] = '0' + decimals;
+	cvt[2] = '0' + exdecimals;
 	cvt[3] = 'f';
 	cvt[4] = 0;
 	snprintf(buf, sizeof(buf), cvt, value);
